# simple-file-configuration.py
Simple File Configurations (not only) for Discord Bots

## Installation
Install using pip:
```
pip install simple-file-configuration
```

## Documentations
have no time rn, documentation may come later, sry
